@@ -8,7 +8,11 @@ import json
 
 from datalab_sdk import DatalabClient, AsyncDatalabClient
 from datalab_sdk.models import ConversionResult, OCRResult, ConvertOptions, OCROptions
-from datalab_sdk.exceptions import DatalabAPIError, DatalabFileError
+from datalab_sdk.exceptions import (
+    DatalabAPIError,
+    DatalabFileError,
+    DatalabTimeoutError,
+)
 
 
 class TestConvertMethod:
@@ -169,6 +173,50 @@ class TestConvertMethod:
                 assert result.html == "<h1>Test Document</h1>"
                 assert result.output_format == "html"
 
+    @pytest.mark.asyncio
+    async def test_convert_async_respects_polling_params(self, temp_dir):
+        """Verify convert passes max_polls and poll_interval to poller"""
+        # Create test file
+        pdf_file = temp_dir / "test.pdf"
+        pdf_file.write_bytes(b"%PDF-1.4\n%Test PDF content\n%%EOF\n")
+
+        # Mock API responses
+        mock_initial_response = {
+            "success": True,
+            "request_id": "rid-1",
+            "request_check_url": "https://api.datalab.to/api/v1/marker/rid-1",
+        }
+
+        mock_result_response = {
+            "success": True,
+            "status": "complete",
+            "output_format": "markdown",
+            "markdown": "ok",
+        }
+
+        async with AsyncDatalabClient(api_key="test-key") as client:
+            with patch.object(
+                client, "_make_request", new_callable=AsyncMock
+            ) as mock_req:
+                with patch.object(
+                    client, "_poll_result", new_callable=AsyncMock
+                ) as mock_poll:
+                    mock_req.return_value = mock_initial_response
+                    mock_poll.return_value = mock_result_response
+
+                    max_polls = 7
+                    poll_interval = 3
+                    await client.convert(
+                        pdf_file, max_polls=max_polls, poll_interval=poll_interval
+                    )
+
+                    mock_poll.assert_awaited_once()
+                    # Verify kwargs were forwarded
+                    args, kwargs = mock_poll.await_args
+                    assert args[0] == mock_initial_response["request_check_url"]
+                    assert kwargs["max_polls"] == max_polls
+                    assert kwargs["poll_interval"] == poll_interval
+
 
 class TestOCRMethod:
     """Test the ocr method"""
@@ -356,6 +404,77 @@ class TestOCRMethod:
                 assert "Page 1 content" in all_text
                 assert "Page 2 content" in all_text
 
+    @pytest.mark.asyncio
+    async def test_ocr_async_respects_polling_params(self, temp_dir):
+        """Verify ocr passes max_polls and poll_interval to poller"""
+        pdf_file = temp_dir / "test.pdf"
+        pdf_file.write_bytes(b"%PDF-1.4\n%Test PDF content\n%%EOF\n")
+
+        mock_initial_response = {
+            "success": True,
+            "request_id": "rid-2",
+            "request_check_url": "https://api.datalab.to/api/v1/ocr/rid-2",
+        }
+
+        mock_result_response = {
+            "success": True,
+            "status": "complete",
+            "pages": [],
+        }
+
+        async with AsyncDatalabClient(api_key="test-key") as client:
+            with patch.object(
+                client, "_make_request", new_callable=AsyncMock
+            ) as mock_req:
+                with patch.object(
+                    client, "_poll_result", new_callable=AsyncMock
+                ) as mock_poll:
+                    mock_req.return_value = mock_initial_response
+                    mock_poll.return_value = mock_result_response
+
+                    max_polls = 11
+                    poll_interval = 2
+                    await client.ocr(
+                        pdf_file, max_polls=max_polls, poll_interval=poll_interval
+                    )
+
+                    mock_poll.assert_awaited_once()
+                    args, kwargs = mock_poll.await_args
+                    assert args[0] == mock_initial_response["request_check_url"]
+                    assert kwargs["max_polls"] == max_polls
+                    assert kwargs["poll_interval"] == poll_interval
+
+    def test_sync_wrappers_forward_polling_params(self, temp_dir):
+        """Ensure sync client forwards polling params to async client"""
+        pdf_file = temp_dir / "test.pdf"
+        pdf_file.write_bytes(b"%PDF-1.4\n%Test PDF content\n%%EOF\n")
+
+        client = DatalabClient(api_key="test-key")
+
+        # Patch async convert/ocr to capture kwargs
+        with patch.object(
+            client._async_client, "convert", new_callable=AsyncMock
+        ) as mock_conv:
+            with patch.object(
+                client._async_client, "ocr", new_callable=AsyncMock
+            ) as mock_ocr:
+                mock_conv.return_value = ConversionResult(
+                    success=True, output_format="markdown", markdown="ok"
+                )
+                mock_ocr.return_value = OCRResult(success=True, pages=[])
+
+                client.convert(pdf_file, max_polls=5, poll_interval=9)
+                client.ocr(pdf_file, max_polls=6, poll_interval=4)
+
+                # Assert called with forwarded kwargs
+                _, conv_kwargs = mock_conv.await_args
+                assert conv_kwargs["max_polls"] == 5
+                assert conv_kwargs["poll_interval"] == 9
+
+                _, ocr_kwargs = mock_ocr.await_args
+                assert ocr_kwargs["max_polls"] == 6
+                assert ocr_kwargs["poll_interval"] == 4
+
 
 class TestClientErrorHandling:
     """Test error handling in client methods"""
@@ -416,3 +535,68 @@ class TestClientErrorHandling:
                 DatalabAPIError, match="Request failed: Processing failed"
             ):
                 client.convert(pdf_file)
+
+    def test_convert_timeout_bubbles_up(self, temp_dir):
+        """Polling timeout surfaces as DatalabTimeoutError for sync convert"""
+        pdf_file = temp_dir / "test.pdf"
+        pdf_file.write_bytes(b"%PDF-1.4\n%Test PDF content\n%%EOF\n")
+
+        mock_initial_response = {
+            "success": True,
+            "request_id": "rid-timeout",
+            "request_check_url": "https://api.datalab.to/api/v1/marker/rid-timeout",
+        }
+
+        client = DatalabClient(api_key="test-key")
+        with patch.object(
+            client._async_client, "_make_request", new_callable=AsyncMock
+        ) as mock_request:
+            with patch.object(
+                client._async_client, "_poll_result", new_callable=AsyncMock
+            ) as mock_poll:
+                mock_request.return_value = mock_initial_response
+                mock_poll.side_effect = DatalabTimeoutError("Polling timed out")
+
+                with pytest.raises(DatalabTimeoutError, match="Polling timed out"):
+                    client.convert(pdf_file)
+
+
+class TestPollingLoop:
+    """Direct tests for the internal polling helper"""
+
+    @pytest.mark.asyncio
+    async def test_poll_result_times_out(self):
+        async with AsyncDatalabClient(api_key="test-key") as client:
+            with (
+                patch.object(
+                    client, "_make_request", new_callable=AsyncMock
+                ) as mock_req,
+                patch("asyncio.sleep", new_callable=AsyncMock) as mock_sleep,
+            ):
+                # Always return processing so we hit timeout
+                mock_req.return_value = {"status": "processing", "success": True}
+
+                with pytest.raises(DatalabTimeoutError):
+                    await client._poll_result(
+                        "https://api.example.com/check", max_polls=3, poll_interval=0
+                    )
+
+                assert mock_req.await_count == 3
+                assert mock_sleep.await_count >= 1
+
+    @pytest.mark.asyncio
+    async def test_poll_result_raises_on_failed_status(self):
+        async with AsyncDatalabClient(api_key="test-key") as client:
+            with patch.object(
+                client, "_make_request", new_callable=AsyncMock
+            ) as mock_req:
+                mock_req.return_value = {
+                    "status": "failed",
+                    "success": False,
+                    "error": "boom",
+                }
+
+                with pytest.raises(DatalabAPIError, match="Processing failed: boom"):
+                    await client._poll_result(
+                        "https://api.example.com/check", max_polls=1, poll_interval=0
+                    )
